from saram.main import *
if __name__ == '__main__': #Execute all code before reading source file, ie. execute import, evaluate def to equal name to main
    if len(sys.argv) != 2: # Count number of arguments which contains the command-line arguments passed to the script if it is not equal to 2 ie for (py main.py 1_arg 2_arg)
        raise ArgumentMissingException
    path = sys.argv[1] #python main.py "path_to/img_dir" ie the argv[1] value
    path = os.path.abspath(path) #Accesing filesystem for Return a normalized absolutized version of the pathname path
    s = saram()
    s.main(path) # Def main to path


#from distutils.core import setup
from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

setup(
  name = 'saram',
  packages = ['saram'], # this must be the same as the name above
  version = '0.1',
  description = 'A library to fetch images from a directory and fetch OCR from it with orientation rotation and pdf support',
  long_description = readme(),
  author = 'Sunim Acharya',
  author_email = 'sunim.54@gmail.com',
  url = 'https://github.com/aryaminus/saram', # use the URL to the github repo
  keywords = ['ocr', 'image', 'pdf'], # arbitrary keywords
  classifiers = [],
  install_requires=[
        'io','os','subprocess','sys','time','PIL','pyocr','wand'
  ],
  include_package_data=True,
  zip_safe=False
)